package tools;
import java.io.File;

/** Helper to get application directories.
 * @author	Louis Royer
 * @author	Flavien Haas
 * @author	JS Auge
 * @version	1.0
 */
public class Directories {
	private String projectName;
	private String dataHomeDirectory;

	/** Constructor with projectName parameter.
	 * @param projectName	name of the project
	 */
	public Directories(String projectName) {
		this.projectName = projectName;
		setDataHomeDirectory();
	}

	/** Setter for dataHomeDirectory. Will create the directory if not already exists.
	 */
	private void setDataHomeDirectory() {
		/* Follow XDG Base Directory Specification
		 * https://specifications.freedesktop.org/basedir-spec/basedir-spec-latest.html
		 */
		String d;
		String os = System.getProperty("os.name");
		if (os.equals("Linux")) {
			d = System.getenv().get("XDG_DATA_HOME");
			if (d == null || d.equals("")) {
				d = System.getProperty("user.home") + "/.local/share";
			}
		} else if (os.equals("Mac")||os.equals("Mac OS X")) {
			/* Apple MacOS X User Data Directory
			 * https://developer.apple.com/library/archive/qa/qa1170/_index.html */
			d = System.getProperty("user.home") + "/Library";
		} else {
			d = ".";
		}
		d += "/" + projectName + "/";
		// create directory if not already exists
		new File(d).mkdirs();
		dataHomeDirectory = d;
	}

	/** Getter for dataHomeDirectory.
	 * @return	path to the application home directory
	 */
	public String getDataHomeDirectory() {
		return dataHomeDirectory;
	}
	
	

}
